#include "shutter.h"
#include "time.h"
#include "lcd_routines.h"
#include "debouncing.h"

#include <util/delay.h>

// Initialisierung
void shutter_init() {
	shutter_working = 0;
}

// Stoppt den Rolladen
void shutter_stop() {
	SWTH_PORT &= ~(1 << SWTH1);
	SWTH_PORT &= ~(1 << SWTH2);
	shutter_working = 0;

	shutter_up = 0;
	shutter_down = 0;

	lcd_clear();
	lcd_setcursor(5, 2);
	lcd_string("STOP");
	_delay_ms(300);

}

// ffnet den Rolladen
void shutter_open() {
	if (shutter_down) { // wenn Runterlauf aktiviert
		shutter_stop();
	}
	if (shutter_up && shutter_working) {
		// do nothing
		return;
	}
	shutter_working = 1;
	SWTH_PORT |= (1 << SWTH1);

	lcd_clear();
	lcd_setcursor(6, 2);
	lcd_string("UP");
}

// schliet den Rolladen
void shutter_close() {
	if (shutter_up) { // wenn Hochlauf aktiviert
		shutter_stop();
	}
	if (shutter_down && shutter_working) {
		// do nothing
		return;
	}
	shutter_working = 1;
	SWTH_PORT |= (1 << SWTH2);

	lcd_clear();
	lcd_setcursor(5, 2);
	lcd_string("DOWN");
}

// fragt die Knpfe und Events ab
void shutter_asker() {
	//ffnen (kurz Drcken)
	if (get_key_short(1 << KEY1)) {
		if (shutter_working) {
			shutter_stop();
			return;
		}
		shutter_up = SHUTTER_UP_PERIODE;
	}

	//Schliessen (kurz Drcken)
	if (get_key_short(1 << KEY0)) {
		if (shutter_working) {
			shutter_stop();
			return;
		}
		shutter_down = SHUTTER_DOWN_PERIODE;
	}

	// Events
	if (!shutter_working) {
		if (shutter_up) {
			shutter_open();
		}
		if (shutter_down) {
			shutter_close();
		}

	}
	if ((!shutter_up && !shutter_down) && shutter_working) {
		shutter_stop();
	}

}
